@@ -7,13 +7,14 @@ import string
 import sys
 
 LINKTALLY_VERSION = '0.1.0'
-VERSION = LINKTALLY_VERSION + '-2'
+VERSION = LINKTALLY_VERSION + '-3'
 
 SDIST_LOC = 'http://plone.org/products/linktally/releases/%s/' \
             'linktally-%s.tar.gz' % (LINKTALLY_VERSION, LINKTALLY_VERSION)
-EGGS = '''
+EXTRA_EGGS = '''
 linktally == %s
 collective.recipe.linktally
+pysqlite == 2.4.0
 ''' % LINKTALLY_VERSION
 
 PRODUCTS = ['']
@@ -33,7 +34,17 @@ class Recipe(object):
         if not self.options.has_key('config'):
             self.options['config'] = os.path.join(location, 'linktally.conf')
 
-        self.options['eggs'] = EGGS
+        eggs = self.options.get('eggs', '')
+        existing_egg_names = [x.split()[0]
+                              for x in eggs.split('\n') if x.strip()]
+        for egg in EXTRA_EGGS.split('\n'):
+            if not egg.strip():
+                continue
+            egg_name = egg.split()[0]
+            if egg_name not in existing_egg_names:
+                eggs += '\n' + egg
+
+        self.options['eggs'] = eggs
         self.options['products'] = self.extracted_dir
         self.options['executable'] = self.name
 
